


******

Bravo!  You have received a Medical Diploma in Ships from   
the Orbital Convergence University International Air and Water Embassy of the Tangerine Planet.  

You are now officially certified to include "ships" in your practice.

******


# ships

---

## description
This is a kit of python3 modules.
		
---		
		
## install
`[ZSH] pip install ships`
